Module: Git
- Defined in:
- lib/git-hooks.rb
Overview
Since the Git gem does not provide us with an api that allows you to use the ‘–keep-index’ option when stashing, we are stuck with this monkey patch.
Defined Under Namespace
Classes: Lib
Since the Git gem does not provide us with an api that allows you to use the ‘–keep-index’ option when stashing, we are stuck with this monkey patch.
Classes: Lib